@@ -15,24 +15,27 @@
  *  License along with this library; if not, write to the Free Software              *
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA       *
  *************************************************************************************/
+#pragma once
 
-#ifndef KSCREEN_WAYLAND_OUTPUT_H
-#define KSCREEN_WAYLAND_OUTPUT_H
-
-// libkscreen
-#include "abstractbackend.h"
-#include "config.h"
-#include "output.h"
-
-// Own
 #include "waylandconfig.h"
 
-#include <QScreen>
-#include <QSize>
-#include <QLoggingCategory>
+#include "abstractbackend.h"
+#include "output.h"
+
 #include <KWayland/Client/outputdevice.h>
 #include <KWayland/Client/registry.h>
 
+#include <QLoggingCategory>
+#include <QScreen>
+#include <QSize>
+
+namespace KWayland
+{
+namespace Client
+{
+class OutputConfiguration;
+}
+}
 
 namespace KScreen
 {
@@ -42,49 +45,41 @@ class WaylandOutput : public QObject
     Q_OBJECT
 
 public:
-    ~WaylandOutput() override;
+    explicit WaylandOutput(quint32 id, WaylandConfig *parent = nullptr);
+    ~WaylandOutput() override = default;
 
     KScreen::OutputPtr toKScreenOutput();
     void updateKScreenOutput(KScreen::OutputPtr &output);
 
     quint32 id() const;
-
+    QString name() const;
     bool enabled() const;
 
     KWayland::Client::OutputDevice* outputDevice() const;
-    void bindOutputDevice(KWayland::Client::Registry *registry, KWayland::Client::OutputDevice *op, quint32 name, quint32 version);
+    void createOutputDevice(KWayland::Client::Registry *registry, quint32 name, quint32 version);
 
-    QString name() const;
-
-    // translation methods
-    KScreen::Output::Rotation toKScreenRotation(const KWayland::Client::OutputDevice::Transform transform) const;
-    KWayland::Client::OutputDevice::Transform toKWaylandTransform(const KScreen::Output::Rotation rotation) const;
-
-    QString toKScreenModeId(int kwaylandmodeid) const;
-    int toKWaylandModeId(const QString &kscreenmodeid) const;
+    bool setWlConfig(KWayland::Client::OutputConfiguration *wlConfig,
+                   const KScreen::OutputPtr &output);
 
 Q_SIGNALS:
-    void complete();
+    void deviceRemoved();
 
-    // only emitted after complete()
+    void complete();
+    // only emitted after complete signal
     void changed();
 
 private:
-    friend WaylandConfig;
-    explicit WaylandOutput(quint32 id, WaylandConfig *parent = nullptr);
     void showOutput();
     QString modeName(const KWayland::Client::OutputDevice::Mode &m) const;
 
     quint32 m_id;
-    KWayland::Client::OutputDevice* m_output;
-    KWayland::Client::Registry* m_registry;
+    KWayland::Client::OutputDevice *m_device;
+    KWayland::Client::Registry *m_registry;
 
-    QMap<KWayland::Client::OutputDevice::Transform, KScreen::Output::Rotation> m_rotationMap;
-    QMap<QString, int> m_modeIdMap; // left-hand-side: KScreen::Mode, right-hand-side: kwayland's mode.id
+    // left-hand-side: KScreen::Mode, right-hand-side: KWayland's mode.id
+    QMap<QString, int> m_modeIdMap;
 };
 
-} // namespace
+}
 
 KSCREEN_EXPORT QDebug operator<<(QDebug dbg, const KScreen::WaylandOutput *output);
-
-#endif
